import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem,
    InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, ConfirmButton, Steps, CheckboxItem, TextAreaItem, Table, BottomBtn
} from '@/components/Common-Library'
import Api from '@/service/api'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Row, Col, Tooltip, Modal, Spin } from 'antd';
import { PtyPicker } from '@/components/Business-Library'
import { Link, withRouter } from 'react-router-dom'
import Ptspta1 from '@/views/Public/Ptspta1'
import Business from '@/views/Public/Business'
import { YwbhPicker1 } from '@/components/Business-Library'


const { Pre, Next, StepWrapper } = Steps
const CodeTable = CodeTableFactory.getInstance()
const confirm = Modal.confirm

@withRouter
@inject('UserContext')
@inject('i18n')
@observer
export default class BasicScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = props.model
        this.bind = Bind.bind(this)
    }

    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props
        const { bchlevelLst } = this.props.extra
        //const {next,pre} = this.props.steps
        if (this.props.flag == true) {
            return <Spin style={{ width: "100%", justifyContent: "center" }} spinning={this.props.flag} />
        }
        return (
            <div style={{ position: 'relative' }}>
                <Business  wrappedComponentRef={ref => (this.com = ref)} page={this} steps={this.props.steps} extra={this.props.extra}  model={this.model} />
                {/* 第一行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/* 业务编号 */}
                                <Label itext="业务编号" />
                            </Col>
                            <Col span={10}>
                                <InputItem InputProps={bind("ownref1")} maxLength={16} disabled={true} desp="业务编号" path="/didgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/* 概要描述 */}
                                <Label itext="概要描述" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam1")} maxLength={40} disabled={true} desp="概要描述" path="/didgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>

                </Row>
                {/* 第二行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 信用证金额 */}
                                <Label itext="信用证最大金额" />
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={{
                                    ...bind("max1_cur"), onChange: val => {
                                        this.model.max1_cur = val
                                        this.model.liqtyp = ""
                                        this.model.swftyp = ""
                                    }
                                }} disabled={true}
                                    code={CodeTable.curtxt} />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("max1_amt")} disabled={true} /> */}
                                <InputItem  disabled={true} InputProps={ {...bind("max1_amt"), type:"amount", cur:this.model.max1_cur} } />
                            </Col>


                        </Row>

                    </Col>
                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 申请人名称 */}
                            <Label itext="申请人名称" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts5_namcn")} disabled={true} maxLength={100} desp="客户中文名称" path="/didgrp/apl/pts/namcn" />
                        </Col>


                    </Col>

                </Row>
                {/* 第三行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 到单金额 */}
                                <Label itext="未到单金额" />
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={{
                                    ...bind("opn1_cur"), onChange: val => {
                                        this.model.opn1_cur = val
                                        this.model.liqtyp = ""
                                        this.model.swftyp = ""
                                    }
                                }}
                                    disabled={true}
                                    code={CodeTable.curtxt} />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("opn1_amt")} disabled={true} desp="Balance" path="/didgrp/cbs/opn1/amt" /> */}
                                <InputItem  disabled={true} InputProps={ {...bind("opn1_amt"), type:"amount", cur:this.model.opn1_cur} } />
                            </Col>
                        </Row>

                    </Col>
                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 受益人名称 */}
                            <Label itext="受益人名称" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts6_namcn")}disabled={true} maxLength={100} desp="客户中文名称" path="/didgrp/ben/pts/namcn" />
                        </Col>
                    </Col>

                </Row >
                {/* 第四行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>

                            <Col span={5} offset={2}>
                                {/* 用证对付方式 */}
                                <Label itext="信用证对付方式" />
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("avbby")} disabled={true} code={CodeTable.avbby} desp="信用证对付方式" path="/didgrp/rec/avbby" />


                            </Col>
                        </Row>

                    </Col>
                    <Col span={12}>



                        <Col span={5} offset={2}>
                            {/* 通知行名称 */}
                            <Label itext="通知行地址" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("pts4_adrcn")}disabled={true}  maxLength={100} desp="中文地址" path="/didgrp/adv/pts/adrcn" />
                        </Col>
                    </Col>

                </Row >

                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>

                            <Col span={5} offset={2}>
                                {/* 开立日期 */}
                                <Label itext="开立日期" />
                            </Col>
                            <Col span={10}>
                                <DatePickerItem InputProps={bind("opndat")} disabled={true} desp="开立日期" path="/didgrp/rec/opndat" />
                            </Col>

                        </Row>

                    </Col>
                    <Col span={12}>

                        <Col span={5} offset={2}>
                            {/* 有效地点 */}
                            <Label itext="有效地点" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("expplc")} disabled={true} maxLength={100} desp="有效地点" path="/didgrp/rec/expplc" />
                        </Col>
                    </Col>

                </Row >


                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 用证对付方式 */}
                                <Label itext="有效日期" />
                            </Col>
                            <Col span={10}>
                                <DatePickerItem InputProps={bind("expdat")} disabled={true} desp="有效日期" path="/didgrp/rec/expdat" />
                            </Col>

                        </Row>

                    </Col>
                    <Col span={12}>

                        <Col span={5} offset={2}>
                            {/* 期限 */}
                            <Label itext="期限" trn="ditdck" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("tenmaxday1")} disabled={true} desp="期限" path="/didgrp/rec/tenmaxday" />
                        </Col>
                    </Col>
                </Row >


                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/* 单据编号 */}
                                <Label itext="单据编号" />
                            </Col>
                            <Col span={10}>

                                <InputItem InputProps={bind("ownref")} maxLength={16} disabled={true} desp="单据编号" path="/bddgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/* 单据描述 */}
                                <Label itext="单据描述" trn="ditdck" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")} disabled={true} maxLength={100} desp="概要描述" path="/bddgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>

                </Row>

                <Row style={{ marginTop: 30 }}>
                    <Col span={24}>
                       <Col span={12}>
                            <Col span={5} offset={2}>
                                {/* 单据描述 */}
                                <Label itext="寄单行修改备注" trn="bdtame" />
                            </Col>
                       </Col>
                       <br/>
                        <Col span={12}  >
                            <Col span={17} offset={7}>
                            <TextAreaItem rows={5} style={{ resize: "none" }} TextAreaItem InputProps={bind("amermk")} desp="修改备注" path="/bddgrp/rec/amermk"/>
                            </Col>
                        </Col>
    
                    </Col>
                    </Row>

                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 单据金额 */}
                                <Label itext="单据金额" trn="ditdck" />
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={{
                                    ...bind("max_cur"), onChange: val => {
                                        this.model.max_cur = val
                                        this.model.liqtyp = ""
                                        this.model.swftyp = ""
                                    }
                                }}
                                disabled={true} code={CodeTable.curtxt} />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("max_amt")} desp="Balance" path="/bddgrp/cbs/max/amt" /> */}
                                <InputItem  InputProps={ {...bind("max_amt"), type:"amount", cur:this.model.max_cur} } />
                            </Col>
                            <Col span={3}></Col>
                            <Col span={5} offset={2}>
                                {/* 交单行费用*/}
                                <Label itext="交单行费用" trn="ditdck" />
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={{
                                    ...bind("feecur"), onChange: val => {
                                        this.model.feecur = val
                                        this.model.liqtyp = ""
                                        this.model.swftyp = ""
                                    }
                                }}
                                disabled={true}  code={CodeTable.curtxt} />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("feeamt")} desp="交单行费用金额" path="/bddgrp/rec/feeamt" /> */}
                                <InputItem InputProps={ {...bind("feeamt"), type:"amount", cur:this.model.feecur} } />
                            </Col>
                            <Col span={3}></Col>
                            <Col span={5} offset={2}>
                                {/* 索偿金额 */}
                                <Label itext="索偿金额" trn="ditdck" />
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={{
                                    ...bind("doccur"), onChange: val => {
                                        this.model.doccur = val
                                        this.model.liqtyp = ""
                                        this.model.swftyp = ""
                                    }
                                }}
                                disabled={true}  code={CodeTable.curtxt} />
                            </Col>
                            <Col span={7} offset={1}>
                                {/* <InputItem InputProps={bind("docamt")} desp="索偿金额" path="/bddgrp/rec/docamt" /> */}
                                <InputItem  InputProps={ {...bind("docamt"), type:"amount", cur:this.model.doccur} } />
                            </Col>
                            <Col span={3}></Col>


                        </Row>

                    </Col>
                    <Col span={12}>

                        <Ptspta1 model={this.model} argArr={{ desc: "寄单行", prefix: 'pts2', url: 'bdtame/prep_ptysel', flg: 'B', datakey: '\\bdtp\\prep\\ptslst' }} />
                    </Col>

                </Row>



                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>


                            <Col span={5} offset={2}>
                                {/* 是否议付 */}
                                <Label itext="是否议付" trn="ditdck" />
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("negsta")} code={CodeTable.yesno} desp="议付标识" path="/bddgrp/rec/negsta" />
                            </Col>

                            <Col span={3}></Col>


                            <Col span={5} offset={2}>
                                {/* 期限 */}
                                <Label itext="期限" trn="ditdck" />
                            </Col>
                            <Col span={12}>
                                <InputItem InputProps={bind("tenmaxday")} desp="期限" path="/bddgrp/rec/tenmaxday" />
                            </Col>

                            <Col span={4} offset={1}>天</Col>



                            <Col span={5} offset={2}>
                                {/* 到期日" */}
                                <Label itext="到期日" trn="ditdck" />
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("matdat")} desp="到期日" path="/bddgrp/rec/matdat" />
                            </Col>

                            <Col span={3}></Col>


                        </Row>

                    </Col>
                    <Col span={12}>

                        <Ptspta1 model={this.model} argArr={{ desc: "收单行", prefix: 'pts3', url: 'bdtame/rcvp_ptysel', flg: 'B', datakey: '\\bdtp\\rcvp\\ptslst' }} />
                    </Col>

                </Row>

                <Row>
                    <Col span={12}>
                        <Row className="row" type='flex'>
                            <Col span={5} offset={2}>
                                {/* 远期付款指示 */}
                                <Label itext="远期付款指示" trn="ditdck" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("payinf")} maxLength={60} desp="远期付款指示" path="/bddgrp/rec/payinf" />
                            </Col>

                        </Row>

                    </Col>
                    <Col span={12}>

                        <Col span={5} offset={2}>
                            {/* 快递单号 */}
                            <Label itext="快递单号" trn="ditdck" />
                        </Col>
                        <Col span={14}>
                            <InputItem InputProps={bind("tranum")} maxLength={60} desp="快递单号" path="/bddgrp/rec/tranum" />
                        </Col>
                    </Col>

                </Row >

                <Row style={{ marginTop: 30 }}>
                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 单据明细 */}
                            <Label itext="单据明细" trn="ditdck" />
                        </Col>

                        <Col span={14}  ><TextAreaItem rows={10} style={{ resize: "none" }} TextAreaItem InputProps={bind("docinf")} desp="单据明细" path="/bddgrp/rec/docinf" /></Col>
                    </Col>

                    <Col span={12}>
                        <Col span={5} offset={2}>
                            {/* 发票信息*/}
                            <Label itext="发票信息" trn="ditdck" />
                        </Col>
                        <Col span={14}><TextAreaItem rows={10} style={{ resize: "none" }} InputItem InputProps={bind("invno")} maxLength={25} desp="发票信息" path="/bddgrp/rec/invno" /></Col>
                    </Col>

                </Row >

                {/* 底部按钮 */}
                <BottomBtn _this={this} />

            </div >
        )
    }
}
