import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem, BottomBtn,
    InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, ConfirmButton, Steps, CheckboxItem, TextAreaItem, Table
} from '@/components/Common-Library'
import Api from '@/service/api'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Row, Col, Tooltip, Modal, Spin } from 'antd';
import { PtyPicker } from '@/components/Business-Library'
import { Link, withRouter } from 'react-router-dom'
import Ptspta1 from '@/views/Public/Ptspta1'
import Business from '@/views/Public/Business'

const { Pre, Next, StepWrapper } = Steps
const CodeTable = CodeTableFactory.getInstance()
const confirm = Modal.confirm

@withRouter
@inject('UserContext')
@inject('i18n')
@observer
export default class OvwpScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = props.model
				this.bind = Bind.bind(this)
    }

    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props
        //const {next,pre} = this.props.steps
        if (this.props.flag == true) {
            return <Spin style={{ width: "100%", justifyContent: "center" }} spinning={this.props.flag} />
        }
        return (
            <div style={{ position: 'relative' }}>
                <Business  wrappedComponentRef={ref => (this.com = ref)} page={this} steps={this.props.steps} extra={this.props.extra}  model={this.model} />
                <Row>
                  <Col span={12}>
										<Row className="row">
                      <Col span={5} offset={2}>
												<Label itext="业务编号" trn="detfre" />
                      </Col>
                      <Col span={14}>
												<InputItem InputProps={bind("ownref")}  maxLength={20}  desp="业务编号" path="/dedgrp/rec/ownref" disabled={true} />
                      </Col>
                    </Row>
									</Col>
                  <Col span={12}>
										<Row className="row">
                      <Col span={5} offset={2}>
												<Label itext="信用证编号" trn="detfre" />
                      </Col>
                      <Col span={14}>
												<InputItem InputProps={bind("lcref")}  maxLength={35}  desp="信用证编号" path="/dedgrp/rec/lcref" disabled={true} />
                      </Col>
                    </Row>
									</Col>
                </Row>

                {/* 第一行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                              <Label itext="信用证金额" trn="detfre" />
                            </Col>
                            <Col span={6}>
                              <SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/dedgrp/cbs/max/cur"  disabled={true}/>
                            </Col>
                            <Col span={7} offset={1}>
                              <InputItem   InputProps={ {...bind("max_amt"), type:"amount", cur:this.model.max_cur} } disabled={true} />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                              <Label itext="受益人" trn="detfre" />
                            </Col>
                            <Col span={14}>
                              <InputItem InputProps={bind("pts1_namcn")}  maxLength={100}  desp="客户中文名称" path="/dedgrp/ben/pts/namcn"  disabled={true} />
                            </Col>
                        </Row>
                    </Col>
                </Row>

                {/* 第二行 */}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                          <Col span={5} offset={2}>
                            <Label itext="信用证余额" trn="detfre" />
						            	</Col>
						            	<Col span={6}>
                            <SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/dedgrp/cbs/opn1/cur"  disabled={true}/>
							            </Col>
							            <Col span={7} offset={1}>
                            <InputItem   InputProps={ {...bind("opn1_amt"), type:"amount", cur:this.model.opn1_cur} } disabled={true} />
							            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                      <Row className="row">
                        <Col span={5} offset={2}>
                          <Label itext="申请人" trn="detfre" />
                        </Col>
                        <Col span={14}>
                          <InputItem InputProps={bind("pts_namcn")}  maxLength={100}  desp="客户中文名称" path="/dedgrp/apl/pts/namcn" disabled={true} />
                        </Col>
                      </Row>
                    </Col>
                </Row>

                {/* 第三行 */}
                <Row>
                    <Col span={12}>
                      <Row className="row">
                        <Col span={5} offset={2}>
                          <Label itext="开立日期" trn="detfre" />	
                        </Col>
                        <Col span={14}>
                          <DatePickerItem InputProps={bind("opndat")}  desp="开立日期" path="/dedgrp/rec/opndat" disabled={true} />
                        </Col>
                      </Row>
                    </Col>
                    <Col span={12}>
                      <Row className="row">
                        <Col span={5} offset={2}>
                          <Label itext="开证行" trn="detfre" />
                        </Col>
                        <Col span={14}>
                          <InputItem InputProps={bind("pts2_namcn")}  maxLength={100}  desp="客户中文名称" path="/dedgrp/iss/pts/namcn" disabled={true} />
                        </Col>
                      </Row>
                    </Col>
                </Row >

                {/* 第四行 */}
                <Row>
                    <Col span={12}>
                      <Row className="row">
                        <Col span={5} offset={2}>
                          <Label itext="信用证兑付方式" trn="detfre" />
                        </Col>
                        <Col span={14}>
                          <SelectItem InputProps={bind("avbby")} code={CodeTable.avbby}  desp="信用证对付方式" path="/dedgrp/rec/avbby" disabled={true}/>
                        </Col>
                      </Row>
                    </Col>
                    <Col span={12}>
                      <Row className="row">
                        <Col span={5} offset={2}>
                          <Label itext="有效地点" trn="detfre" />
                        </Col>
                        <Col span={14}>
                          <InputItem InputProps={bind("expplc")}  maxLength={100}  desp="有效地点" path="/dedgrp/rec/expplc" disabled={true} />
                        </Col>
                      </Row>
                    </Col>
                </Row >

                <Row>
                    <Col span={12}>
                        <Row className="row">
                          <Col span={5} offset={2}>
                            <Label itext="报文内容" trn="detfre" />	
                          </Col>
												</Row>
												<Row className="row">
                          <Col span={19} offset={2}>
                            <TextAreaItem InputProps={bind("fremsg_fretxt")} rows={6} style={{ resize: "none" }} desp="Narrative" path="/fremsg/fretxt"/>
                          </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                      <Col span={24}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                              <Label itext="有效日期" trn="detfre" />
                            </Col>
                            <Col span={14}>
                              <DatePickerItem InputProps={bind("expdat")}  desp="有效日期" path="/dedgrp/rec/expdat" disabled={true} />
                            </Col>
                        </Row> 
                      </Col>
                      <Col span={24}>
                        <Ptspta1 model={this.model} argArr={{ desc: "收报行", prefix: 'pts3', url: 'detfre/fmcp_ptysel', flg: 'B', datakey: '\\fremsg\\fmcp\\ptslst' }}  />
                      </Col>
                    </Col>
                </Row >
                
                {/* 底部按钮 */}
                <BottomBtn _this={this} />
            </div >
        )
    }
}
