import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mDitame from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class DitameScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'ditame'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mDitame()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('ditame/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]
    liaccv_liaccvgHeader=[
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原始金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算账号" />, 
    		dataIndex:"cusact",
    		key:"cusact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cusact,r2.cusact),
    	},
    	{
    		title:<Label itext="保证金账号" />, 
    		dataIndex:"ccvact",
    		key:"ccvact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvact,r2.ccvact),
    	},
    	{
    		title:<Label itext="记账" />, 
    		dataIndex:"gleflg",
    		key:"gleflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.gleflg,r2.gleflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.onsel.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    liaall_liaallgHeader=[
    	{
    		title:<Label itext="业务种类" />, 
    		dataIndex:"bussec",
    		key:"bussec",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.bussec,r2.bussec),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.bussec.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="表外类型" />, 
    		dataIndex:"liatyp",
    		key:"liatyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.liatyp,r2.liatyp),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="表外账号" />, 
    		dataIndex:"acc",
    		key:"acc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acc,r2.acc),
    	},
    ]


    //按钮事件
    onA2bp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/a2bp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/aplp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAgep_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/agep_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onNegp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/negp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/advp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAgep_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/agep_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaall_astlia= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/liaall_astlia',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/aplp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/benp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onA2bp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/a2bp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onConp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/conp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaccv_recalccv= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/liaccv_recalccv',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onNegp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/negp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/benp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/advp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onConp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditame/conp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="业务编号" path="/didgrp/rec/ownref" />
	<InputItem InputProps={bind("nam")}  maxLength={100}  desp="概要描述" path="/didgrp/rec/nam" />
	<DatePickerItem InputProps={bind("amedat")}  desp="最后修改日期" path="/didgrp/rec/amedat" />
	<InputItem InputProps={bind("amenbr")}   desp="修改次数" path="/didgrp/rec/amenbr" />
	<InputItem InputProps={bind("nomtop1")}   desp="上浮" path="/olddidgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton1")}   desp="下浮" path="/olddidgrp/rec/nomton" />
	<InputItem InputProps={bind("nomtop")}   desp="上浮" path="/didgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton")}   desp="下浮" path="/didgrp/rec/nomton" />
	<SelectItem InputProps={bind("nom11_cur")} code={CodeTable.curtxt}  desp="Currency" path="/olddidgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom11_amt")}   desp="Balance" path="/olddidgrp/cbs/nom1/amt" />
	<SelectItem InputProps={bind("max1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/olddidgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max1_amt")}   desp="Balance" path="/olddidgrp/cbs/max/amt" />
	<SelectItem InputProps={bind("ditamep_engcur")} code={CodeTable.curtxt}  desp="Engagement Currency" path="/ditamep/engcur"/>
	<InputItem InputProps={bind("ditamep_engamt")}   desp="change of engagement:" path="/ditamep/engamt" />
	<SelectItem InputProps={bind("ditamep_maxcur")} code={CodeTable.curtxt}  desp="Currency of Maximum Amount" path="/ditamep/maxcur"/>
	<InputItem InputProps={bind("ditamep_maxamt")}   desp="New Maximum Amount" path="/ditamep/maxamt" />
	<SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/nom1/cur"/>
	<InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/didgrp/cbs/nom1/amt" />
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/didgrp/cbs/max/amt" />
	<DatePickerItem InputProps={bind("expdat1")}  desp="有效日期" path="/olddidgrp/rec/expdat" />
	<DatePickerItem InputProps={bind("shpdat1")}  desp="最迟货物装运/服务提供日期 " path="/olddidgrp/rec/shpdat" />
	<DatePickerItem InputProps={bind("expdat")}  desp="有效日期" path="/didgrp/rec/expdat" />
	<DatePickerItem InputProps={bind("shpdat")}  desp="最迟货物装运/服务提供日期 " path="/didgrp/rec/shpdat" />
	<InputItem InputProps={bind("expplc1")}  maxLength={100}  desp="有效地点" path="/olddidgrp/rec/expplc" />
	<InputItem InputProps={bind("expplc")}  maxLength={100}  desp="有效地点" path="/didgrp/rec/expplc" />
	<SelectItem InputProps={bind("rejameflg")} code={CodeTable.rejcod}  desp="拒绝修改标识" path="/didgrp/rec/rejameflg"/>
	<InputItem InputProps={bind("rejreason")}  maxLength={60}  desp="通知行拒绝理由" path="/didgrp/rec/rejreason" />
	<Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
		<Label   itext="获取"/>
	</Button>
	<SelectItem InputProps={bind("ownbch")}   desp="归属机构" path="/didgrp/rec/ownbch"/>
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/apl/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAplp_sel} desp="查询" path="/ditp/aplp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAplp_ptysel} desp="客户查询" path="/ditp/aplp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<InputItem InputProps={bind("accusr")}  maxLength={8}  desp="客户经理" path="/didgrp/rec/accusr" />
	<InputItem InputProps={bind("pts3_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/apl/pts/namcn" />
	<DatePickerItem InputProps={bind("opndat")}  desp="开立日期" path="/didgrp/rec/opndat" />
	<InputItem InputProps={bind("pts3_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/apl/pts/adrcn" />
	<InputItem InputProps={bind("pts3_extact")}  maxLength={32}  desp="结算账号" path="/didgrp/apl/pts/extact" />
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/ben/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onBenp_sel} desp="查询" path="/ditp/benp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onBenp_ptysel} desp="客户查询" path="/ditp/benp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<InputItem InputProps={bind("pts4_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/ben/pts/namcn" />
	<SelectItem InputProps={bind("isstyp")} code={CodeTable.isstyp}  desp="开证类型" path="/didgrp/rec/isstyp"/>
	<InputItem InputProps={bind("pts4_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/ben/pts/adrcn" />
	<SelectItem InputProps={bind("trdtyp")} code={CodeTable.trdtyp}  desp="贸易方式" path="/didgrp/rec/trdtyp"/>
	<InputItem InputProps={bind("pts4_extact")}  maxLength={32}  desp="结算账号" path="/didgrp/ben/pts/extact" />
	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/adv/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAdvp_sel} desp="查询" path="/ditp/advp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAdvp_ptysel} desp="客户查询" path="/ditp/advp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby}  desp="信用证对付方式" path="/didgrp/rec/avbby"/>
	<InputItem InputProps={bind("tenmaxday")}   desp="期限" path="/didgrp/rec/tenmaxday" />
	<InputItem InputProps={bind("pts1_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/adv/pts/namcn" />
	<InputItem InputProps={bind("pts1_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/adv/pts/adrcn" />
	<InputItem InputProps={bind("defdet")}  maxLength={60}  desp="远期付款指示" path="/didgrp/rec/defdet" />
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/a2b/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onA2bp_sel} desp="查询" path="/ditp/a2bp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onA2bp_ptysel} desp="客户查询" path="/ditp/a2bp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/age/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAgep_sel} desp="查询" path="/ditp/agep/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAgep_ptysel} desp="客户查询" path="/ditp/agep/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<InputItem InputProps={bind("pts_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/a2b/pts/namcn" />
	<InputItem InputProps={bind("pts2_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/age/pts/namcn" />
	<InputItem InputProps={bind("pts_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/a2b/pts/adrcn" />
	<InputItem InputProps={bind("pts2_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/age/pts/adrcn" />
	<InputItem InputProps={bind("conno")}  maxLength={35}  desp="合同编号" path="/didgrp/rec/conno" />
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/con/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onConp_sel} desp="查询" path="/ditp/conp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onConp_ptysel} desp="客户查询" path="/ditp/conp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<InputItem InputProps={bind("concur")}  maxLength={3}  desp="合同币种" path="/didgrp/rec/concur" />
	<InputItem InputProps={bind("conamt")}   desp="合同金额" path="/didgrp/rec/conamt" />
	<InputItem InputProps={bind("pts5_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/con/pts/namcn" />
	<SelectItem InputProps={bind("shppar")} code={CodeTable.allow}  desp="分批装运货物/分次提供服务" path="/didgrp/rec/shppar"/>
	<InputItem InputProps={bind("pts5_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/con/pts/adrcn" />
	<SelectItem InputProps={bind("shpper")} code={CodeTable.allow}  desp="分期装运/提供服务" path="/didgrp/rec/shpper"/>
	<SelectItem InputProps={bind("shptrs")} code={CodeTable.allow}  desp="转运" path="/didgrp/rec/shptrs"/>
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/neg/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onNegp_sel} desp="查询" path="/ditp/negp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onNegp_ptysel} desp="客户查询" path="/ditp/negp/ptysel">
		<Label   itext="客户查询"/>
	</Button>
	<SelectItem InputProps={bind("traflg")} code={CodeTable.yesno}  desp="是否可转让" path="/didgrp/rec/traflg"/>
	<InputItem InputProps={bind("pts7_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/neg/pts/namcn" />
	<SelectItem InputProps={bind("cfmflg")} code={CodeTable.yesno}  desp="保兑标志" path="/didgrp/rec/cfmflg"/>
	<InputItem InputProps={bind("pts7_adrcn")}  maxLength={100}  desp="中文地址" path="/didgrp/neg/pts/adrcn" />
	<SelectItem InputProps={bind("negflg")} code={CodeTable.design}  desp="指定议付行" path="/didgrp/rec/negflg"/>
	<InputItem InputProps={bind("tratyp")}  maxLength={20}  desp="货物运输或交货方式/服务方式" path="/didgrp/rec/tratyp" />
	<InputItem InputProps={bind("trdapt")}  maxLength={100}  desp="分期装运/提供服务约定" path="/didgrp/rec/trdapt" />
	<InputItem InputProps={bind("preper")}  maxLength={100}  desp="交单期限" path="/didgrp/rec/preper" />
	<InputItem InputProps={bind("shpfro")}  maxLength={100}  desp="货物装运地(港)" path="/didgrp/rec/shpfro" />
	<InputItem InputProps={bind("shpto")}  maxLength={100}  desp="货物目的地、交货地（港）" path="/didgrp/rec/shpto" />
	<InputItem InputProps={bind("shppro")}  maxLength={100}  desp="服务提供地点" path="/didgrp/rec/shppro" />
	<TextAreaItem InputProps={bind("adlcndame1")} desp="附加条款历史修改记录" path="/olddidgrp/rec/adlcndame"/>
	<TextAreaItem InputProps={bind("adlcnd1")} desp="附加条款" path="/olddidgrp/rec/adlcnd"/>
	<TextAreaItem InputProps={bind("adlcnd")} desp="附加条款" path="/didgrp/rec/adlcnd"/>
	<TextAreaItem InputProps={bind("lcrgodame1")} desp="货物/服务描述修改记录" path="/olddidgrp/rec/lcrgodame"/>
	<TextAreaItem InputProps={bind("lcrgod1")} desp="货物服务描述" path="/olddidgrp/rec/lcrgod"/>
	<TextAreaItem InputProps={bind("lcrgod")} desp="货物服务描述" path="/didgrp/rec/lcrgod"/>
	<TextAreaItem InputProps={bind("lcrdocame1")} desp="单据要求历史修改记录" path="/olddidgrp/rec/lcrdocame"/>
	<TextAreaItem InputProps={bind("lcrdoc1")} desp="单据要求" path="/olddidgrp/rec/lcrdoc"/>
	<TextAreaItem InputProps={bind("lcrdoc")} desp="单据要求" path="/didgrp/rec/lcrdoc"/>
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
	<InputItem InputProps={bind("inr")}  maxLength={8}  desp="索引" path="/didgrp/rec/inr" />
	<SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="最高金额限额" path="/didgrp/rec/nomspc"/>
	<InputItem InputProps={bind("ownusr")}  maxLength={8}  desp="创建柜员" path="/didgrp/rec/ownusr" />
	<DatePickerItem InputProps={bind("credat")}  desp="创建日期" path="/didgrp/rec/credat" />
	<DatePickerItem InputProps={bind("clsdat")}  desp="闭卷日期" path="/didgrp/rec/clsdat" />
	<DatePickerItem InputProps={bind("preadvdat")}  desp="预开立日期" path="/didgrp/rec/preadvdat" />
	<InputItem InputProps={bind("utlnbr")}   desp="收单次数" path="/didgrp/rec/utlnbr" />
	<InputItem InputProps={bind("ver")}  maxLength={4}  desp="版本号" path="/didgrp/rec/ver" />
	<CheckboxItem InputProps={bind("rejflg")}  desp="拒绝标识" path="/didgrp/rec/rejflg" />
	<InputItem InputProps={bind("etyextkey")}  maxLength={8}  desp="实体" path="/didgrp/rec/etyextkey" />
	<InputItem InputProps={bind("rejamenbr")}   desp="拒绝接受修改次数" path="/didgrp/rec/rejamenbr" />
	<SelectItem InputProps={bind("clsinf")} code={CodeTable.clsinf}  desp="注销/闭卷原因" path="/didgrp/rec/clsinf"/>
	<InputItem InputProps={bind("usrbch")}  maxLength={8}  desp="经办机构" path="/didgrp/rec/usrbch" />
	<TextAreaItem InputProps={bind("adlcndame")} desp="附加条款历史修改记录" path="/didgrp/rec/adlcndame"/>
	<TextAreaItem InputProps={bind("lcrgodame")} desp="货物/服务描述修改记录" path="/didgrp/rec/lcrgodame"/>
	<TextAreaItem InputProps={bind("lcrdocame")} desp="单据要求历史修改记录" path="/didgrp/rec/lcrdocame"/>
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/iss/pts/extkey" />
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>
	<SelectItem InputProps={bind("ccvamt_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/ccvamt/cur"/>
	<InputItem InputProps={bind("ccvamt_amt")}   desp="Balance" path="/didgrp/cbs/ccvamt/amt" />
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>
	<Button  type="primary"  onClick={this.onLiaall_astlia} desp="表外加载" path="/liaall/astlia">
		<Label   itext="表外加载"/>
	</Button>
	<Table rowKey="inr" columns={this.liaall_liaallgHeader}  dataSource={this.model.liaall_liaallg}   path="/liaall/liaallg"/>
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />
	<SelectItem InputProps={bind("liaccv_concur")} code={CodeTable.curtxt}  desp="业务结算币种" path="/liaall/liaccv/concur"/>
	<InputItem InputProps={bind("liaccv_newamt")}   desp="业务金额" path="/liaall/liaccv/newamt" />
	<InputItem InputProps={bind("liaccv_cshpct")}   desp="保证金应收比例" path="/liaall/liaccv/cshpct" />
	<InputItem InputProps={bind("liaccv_chgamt")}   desp="变动金额" path="/liaall/liaccv/chgamt" />
	<InputItem InputProps={bind("liaccv_relcshpct")}   desp="保证金实收比例" path="/liaall/liaccv/relcshpct" />
	<InputItem InputProps={bind("liaccv_pctresamt")}   desp="应收/支保证金" path="/liaall/liaccv/pctresamt" />
	<Button  type="primary"  onClick={this.onLiaccv_recalccv} desp="汇率重算" path="/liaall/liaccv/recalccv">
		<Label   itext="汇率重算"/>
	</Button>
	<Table rowKey="inr" columns={this.liaccv_liaccvgHeader}  dataSource={this.model.liaccv_liaccvg}   path="/liaall/liaccv/liaccvg"/>
	<InputItem InputProps={bind("liaccv_totcovamt")}   desp="保证金合计" path="/liaall/liaccv/totcovamt" />
		</div>
		)
	}
}
