import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mDitfee from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class DitfeeScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'ditfee'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mDitfee()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('ditfee/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]


    //按钮事件
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('ditfee/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
	<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/max/cur"/>
	<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/didgrp/cbs/max/amt" />
	<InputItem InputProps={bind("pts3_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/apl/pts/namcn" />
	<SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/opn1/cur"/>
	<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/didgrp/cbs/opn1/amt" />
	<InputItem InputProps={bind("pts4_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/ben/pts/namcn" />
	<InputItem InputProps={bind("pts1_namcn")}  maxLength={100}  desp="客户中文名称" path="/didgrp/adv/pts/namcn" />
	<DatePickerItem InputProps={bind("opndat")}  desp="开立日期" path="/didgrp/rec/opndat" />
	<InputItem InputProps={bind("expplc")}  maxLength={100}  desp="有效地点" path="/didgrp/rec/expplc" />
	<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby}  desp="信用证对付方式" path="/didgrp/rec/avbby"/>
	<InputItem InputProps={bind("tenmaxday")}   desp="期限" path="/didgrp/rec/tenmaxday" />
	<DatePickerItem InputProps={bind("expdat")}  desp="有效日期" path="/didgrp/rec/expdat" />
	<InputItem InputProps={bind("inr")}  maxLength={8}  desp="索引" path="/didgrp/rec/inr" />
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_feedet} desp="重算金额" path="/setmod/feedet">
		<Label   itext="重算金额"/>
	</Button>
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />
	<InputItem InputProps={bind("nam")}  maxLength={100}  desp="概要描述" path="/didgrp/rec/nam" />
	<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="业务编号" path="/didgrp/rec/ownref" />
	<SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="最高金额限额" path="/didgrp/rec/nomspc"/>
	<InputItem InputProps={bind("nomtop")}   desp="上浮" path="/didgrp/rec/nomtop" />
	<InputItem InputProps={bind("nomton")}   desp="下浮" path="/didgrp/rec/nomton" />
	<SelectItem InputProps={bind("isstyp")} code={CodeTable.isstyp}  desp="开证类型" path="/didgrp/rec/isstyp"/>
	<SelectItem InputProps={bind("trdtyp")} code={CodeTable.trdtyp}  desp="贸易方式" path="/didgrp/rec/trdtyp"/>
	<InputItem InputProps={bind("tratyp")}  maxLength={20}  desp="货物运输或交货方式/服务方式" path="/didgrp/rec/tratyp" />
	<InputItem InputProps={bind("shpfro")}  maxLength={100}  desp="货物装运地(港)" path="/didgrp/rec/shpfro" />
	<InputItem InputProps={bind("shpto")}  maxLength={100}  desp="货物目的地、交货地（港）" path="/didgrp/rec/shpto" />
	<InputItem InputProps={bind("shppro")}  maxLength={100}  desp="服务提供地点" path="/didgrp/rec/shppro" />
	<InputItem InputProps={bind("preper")}  maxLength={100}  desp="交单期限" path="/didgrp/rec/preper" />
	<DatePickerItem InputProps={bind("shpdat")}  desp="最迟货物装运/服务提供日期 " path="/didgrp/rec/shpdat" />
	<SelectItem InputProps={bind("shppar")} code={CodeTable.allow}  desp="分批装运货物/分次提供服务" path="/didgrp/rec/shppar"/>
	<SelectItem InputProps={bind("shpper")} code={CodeTable.allow}  desp="分期装运/提供服务" path="/didgrp/rec/shpper"/>
	<InputItem InputProps={bind("trdapt")}  maxLength={100}  desp="分期装运/提供服务约定" path="/didgrp/rec/trdapt" />
	<SelectItem InputProps={bind("shptrs")} code={CodeTable.allow}  desp="转运" path="/didgrp/rec/shptrs"/>
	<InputItem InputProps={bind("defdet")}  maxLength={60}  desp="远期付款指示" path="/didgrp/rec/defdet" />
	<InputItem InputProps={bind("conno")}  maxLength={35}  desp="合同编号" path="/didgrp/rec/conno" />
	<InputItem InputProps={bind("concur")}  maxLength={3}  desp="合同币种" path="/didgrp/rec/concur" />
	<InputItem InputProps={bind("conamt")}   desp="合同金额" path="/didgrp/rec/conamt" />
	<SelectItem InputProps={bind("negflg")} code={CodeTable.design}  desp="指定议付行" path="/didgrp/rec/negflg"/>
	<SelectItem InputProps={bind("traflg")} code={CodeTable.yesno}  desp="是否可转让" path="/didgrp/rec/traflg"/>
	<SelectItem InputProps={bind("cfmflg")} code={CodeTable.yesno}  desp="保兑标志" path="/didgrp/rec/cfmflg"/>
	<TextAreaItem InputProps={bind("lcrgod")} desp="货物服务描述" path="/didgrp/rec/lcrgod"/>
	<TextAreaItem InputProps={bind("lcrdoc")} desp="单据要求" path="/didgrp/rec/lcrdoc"/>
	<TextAreaItem InputProps={bind("adlcnd")} desp="附加条款" path="/didgrp/rec/adlcnd"/>
	<InputItem InputProps={bind("ownusr")}  maxLength={8}  desp="创建柜员" path="/didgrp/rec/ownusr" />
	<DatePickerItem InputProps={bind("credat")}  desp="创建日期" path="/didgrp/rec/credat" />
	<DatePickerItem InputProps={bind("clsdat")}  desp="闭卷日期" path="/didgrp/rec/clsdat" />
	<DatePickerItem InputProps={bind("amedat")}  desp="最后修改日期" path="/didgrp/rec/amedat" />
	<InputItem InputProps={bind("amenbr")}   desp="修改次数" path="/didgrp/rec/amenbr" />
	<DatePickerItem InputProps={bind("preadvdat")}  desp="预开立日期" path="/didgrp/rec/preadvdat" />
	<InputItem InputProps={bind("utlnbr")}   desp="收单次数" path="/didgrp/rec/utlnbr" />
	<InputItem InputProps={bind("ver")}  maxLength={4}  desp="版本号" path="/didgrp/rec/ver" />
	<CheckboxItem InputProps={bind("rejflg")}  desp="拒绝标识" path="/didgrp/rec/rejflg" />
	<InputItem InputProps={bind("etyextkey")}  maxLength={8}  desp="实体" path="/didgrp/rec/etyextkey" />
	<InputItem InputProps={bind("rejamenbr")}   desp="拒绝接受修改次数" path="/didgrp/rec/rejamenbr" />
	<SelectItem InputProps={bind("clsinf")} code={CodeTable.clsinf}  desp="注销/闭卷原因" path="/didgrp/rec/clsinf"/>
	<InputItem InputProps={bind("rejameflg")}  maxLength={4}  desp="拒绝修改标识" path="/didgrp/rec/rejameflg" />
	<InputItem InputProps={bind("accusr")}  maxLength={8}  desp="客户经理" path="/didgrp/rec/accusr" />
	<SelectItem InputProps={bind("ownbch")}   desp="归属机构" path="/didgrp/rec/ownbch"/>
	<InputItem InputProps={bind("usrbch")}  maxLength={8}  desp="经办机构" path="/didgrp/rec/usrbch" />
	<TextAreaItem InputProps={bind("adlcndame")} desp="附加条款历史修改记录" path="/didgrp/rec/adlcndame"/>
	<TextAreaItem InputProps={bind("lcrgodame")} desp="货物/服务描述修改记录" path="/didgrp/rec/lcrgodame"/>
	<TextAreaItem InputProps={bind("lcrdocame")} desp="单据要求历史修改记录" path="/didgrp/rec/lcrdocame"/>
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/ben/pts/extkey" />
	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/adv/pts/extkey" />
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/apl/pts/extkey" />
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/a2b/pts/extkey" />
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/iss/pts/extkey" />
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/age/pts/extkey" />
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/neg/pts/extkey" />
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/didgrp/con/pts/extkey" />
	<InputItem InputProps={bind("rejreason")}  maxLength={60}  desp="通知行拒绝理由" path="/didgrp/rec/rejreason" />
	<SelectItem InputProps={bind("ccvamt_cur")} code={CodeTable.curtxt}  desp="Currency" path="/didgrp/cbs/ccvamt/cur"/>
	<InputItem InputProps={bind("ccvamt_amt")}   desp="Balance" path="/didgrp/cbs/ccvamt/amt" />
		</div>
		)
	}
}
