import React, { Component, Fragment } from 'react'
import {
	Page, Validator, Notification, FormItem,
	InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, ConfirmButton, Steps
} from '@/components/Common-Library'
import Api from '@/service/api'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Row, Col, Popconfirm, Modal, Spin } from 'antd';
import { PtyPicker } from '@/components/Business-Library'
import { Link, withRouter } from 'react-router-dom'
import Ptspta1 from '@/views/Public/Ptspta1'
import Business from '@/views/Public/Business'

const { Pre, Next, StepWrapper } = Steps
const CodeTable = CodeTableFactory.getInstance()
const confirm = Modal.confirm

@withRouter
@inject('UserContext')
@inject('i18n')
@observer
export default class OvwpScreen extends Page {
	@observable
	formBlur = false

	constructor(props) {
		super(props)
		this.model = props.model
		this.bind = Bind.bind(this)
		this.pageHide = true

	}

	//交易内实现
	renderPage() {
		const bind = this.bind
		const { i18n } = this.props
		const { bchlevelLst } = this.props.extra
		//const {next,pre} = this.props.steps
		if (this.props.flag == true) {
			return <Spin style={{ width: "100%", justifyContent: "center" }} spinning={this.props.flag} />
		}
		return (
			<div style={{ position: 'relative' }}>
				<Business wrappedComponentRef={ref => (this.com = ref)} extra={this.props.extra} model={this.model} />
				{/* 第一行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* 业务编号 */}
								<Label itext="业务编号" />
							</Col>
							<Col span={14}>
							<InputItem InputProps={bind("ownref")}  maxLength={16}  disabled={true} desp="业务编号" path="/didgrp/rec/ownref" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* 概要描述 */}
								<Label itext="概要描述" />
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("nam")} maxLength={40} desp="概要描述" path="/didgrp/rec/nam" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第二行 */}
				<Row>
					<Col span={12}>
						<Row className="row" type='flex'>
							<Col span={5} offset={2}>
								{/* 归属机构*/}
								<Label itext="归属机构" />
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("ownbch")} code={bchlevelLst} desp="归属机构" path="/didgrp/rec/ownbch" />
							</Col>
							<Col span={3}>

							</Col>
							<Col span={5} offset={2}>
								{/* 归属机构*/}
								<Label itext="客户经理" />
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("accusr")} maxLength={8} desp="客户经理" path="/didgrp/rec/accusr" />
							</Col>
							<Col span={3}>

							</Col>
							<Col span={5} offset={2}>
								{/* 清算路径 */}
								<Label itext="开立日期" />
							</Col>
							<Col span={10}>
								<DatePickerItem InputProps={bind("opndat")} desp="开立日期" path="/didgrp/rec/opndat" />
							</Col>
							<Col span={7}>

							</Col>


						</Row>

					</Col>
					<Col span={12}>
						<Ptspta1 model={this.model} argArr={{ desc: "申请人", prefix: 'pts3', url: 'ditopn/aplp_ptysel', flg: 'C', datakey: '\\ditp\\aplp\\ptslst' }} />
					</Col>

				</Row>
				{/* 第三行 */}
				<Row>
					<Col span={12}>
						<Row className="row" type='flex'>
							<Col span={5} offset={2}>
								{/* 信用证金额 */}
								<Label itext="信用证金额" />
							</Col> 
							<Col span={6}>
								<SelectItem InputProps={{
									...bind("max_cur"), onChange: val => {
										this.model.max_cur = val
										this.model.liqtyp = ""
										this.model.swftyp = ""
									}
								}}
									code={CodeTable.curtxt} />
							</Col>
							<Col span={7} offset={1}>
								<InputItem InputProps={bind("max_amt")} />
							</Col>

							<Col span={5} offset={2}>
								{/* 开证类型 */}
								<Label itext="开证类型" />
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("isstyp")} code={CodeTable.isstyp} desp="开证类型" path="/didgrp/rec/isstyp" />
							</Col>
							<Col span={3}>

							</Col>

							<Col span={5} offset={2}>
								{/* 清算路径 */}
								<Label itext="贸易方式" />
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("trdtyp")} code={CodeTable.trdtyp} desp="贸易方式" path="/didgrp/rec/trdtyp" />
							</Col>
							<Col span={3}>

							</Col>
							<Col span={5} offset={2}>
								{/* 最迟货物装运/服务提供日期 */}
								<Label itext="最迟货物装运日期" />
							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("shpdat")} desp="最迟货物装运/服务提供日期 " path="/didgrp/rec/shpdat" />
							</Col>
							<Col span={3}>

							</Col>

						</Row>
					</Col>

					<Col span={12}>
						<Col span={5} offset={2}>
							{/* 申请人账号 */}
							<Label itext="申请人账号" />
						</Col>
						<Col span={14}>
							<InputItem InputProps={bind("pts3_extact")} maxLength={32} desp="申请人账号" path="/didgrp/apl/pts/extact" />
						</Col>
						<Col span={3}>

						</Col>
						<Ptspta1 model={this.model} argArr={{ desc: "受益人", prefix: 'pts4', url: 'ditopn/benp_ptysel', flg: 'C', datakey: '\\ditp\\benp\\ptslst' }} />
					</Col>
				</Row >
				{/* 第四行 */}
				{/* 第五行 */}
				<Row>
					<Col span={12}>
						<Row className="row" type='flex'>


							<Col span={5} offset={2}>
								{/* 信用证对付方式 */}
								<Label itext="信用证对付方式" />
							</Col>
							<Col span={7}>
								<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby} desp="信用证对付方式" path="/didgrp/rec/avbby" />
							</Col>
							<Col span={4} offset={1}>
								<InputItem InputProps={bind("tenmaxday")} desp="期限" path="/didgrp/rec/tenmaxday" />

							</Col>
							<Col span={4} offset={1}>
								<Label itext="天" />
							</Col>

							<Col span={5} offset={2}>
								{/* 有效日期 */}
								<Label itext="有效日期" />
							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("expdat")} desp="有效日期" path="/didgrp/rec/expdat" />
							</Col>
							{/* <Col span={4} offset={2}>
								<InputItem InputProps={bind("tenmaxday")} desp="期限" path="/didgrp/rec/tenmaxday" />

							</Col>
							<Col span={4} offset={1}>
								<Label itext="天" />
							</Col> */}
							<Col span={3}></Col>

							<Col span={5} offset={2}>
								{/* 远期付款指示 */}
								<Label itext="远期付款指示" />
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("defdet")} code={CodeTable.avbby} desp="远期付款指示" path="/didgrp/rec/defdet" />
							</Col>
							<Col span={3}>

							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Col span={5} offset={2}>
							{/* 受益人账号 */}
							<Label itext="受益人账号" />
						</Col>
						<Col span={14}>
							<InputItem InputProps={bind("pts4_extact")} maxLength={32} desp="结算账号" path="/didgrp/ben/pts/extact" />
						</Col>
						<Col span={3}>

						</Col>
						<Ptspta1 model={this.model} argArr={{ desc: "通知行", prefix: 'pts1', url: 'ditopn/advp_ptysel', flg: 'C', datakey: '\\ditp\\advp\\ptslst' }} />
						
					</Col>
				</Row>

			</div >
		)
	}
}
