import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLetopn from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Row, Col, Popconfirm, Modal, Spin } from 'antd';
import Ptspta from '@/views/Public/Ptspta'
import { PtyPicker } from '@/components/Business-Library'
import Business from '@/views/Public/Business'

const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class LetopnScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'letopn'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLetopn()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('letopn/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]


    //按钮事件
    onPts1_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts1_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInsbnk_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/insbnk_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/rmbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/drwp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPreper_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/preper_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/aplp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/avbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts8_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts8_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts8_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts8_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onApbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/apbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/advp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts7_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts7_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/rmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrgod_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/lcrgod_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onA2bp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/a2bp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/aplp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDocmod_doclst= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/docmod_doclst',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onApbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/apbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onIssp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/issp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/advp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts5_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts5_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts4_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts4_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts6_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts6_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts5_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts5_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts1_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts1_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/avbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/drwp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCharia_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/charia_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/benp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onA2bp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/a2bp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts7_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts7_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdoc_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/lcrdoc_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdlcnd_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/adlcnd_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/benp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts2_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_ref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/pts3_ref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdftat_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/lcrdftat_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onIssp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('letopn/issp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
        {/*第一行*/}
       <Row>
            <Col span={12}>
                <Row className="row">
                    <Col span={5} offset={2}>
                        {/*reference*/}
                        <Label itext="Reference"/>
                    </Col>
                    <Col span={10}>
                        <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/ledgrp/rec/ownref" />
	                </Col>
                    <Col span={4} offset={1}>
                        <Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
		                   <Label   itext="获取"/>
	                    </Button>
                    </Col>
                </Row>
            </Col>
            <Col span={12}>
                <Row className="row">
                    <Col span={5} offset={2}>
                        {/* Name*/}
                        <Label itext="Name"/>
                    </Col>
                    <Col span={14}>
                        <InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/ledgrp/rec/nam" />
                    </Col>
                </Row>
            </Col>
        </Row>
        {/*第二行*/}
        <Row>
            <Col span={12}>
                <Row className="row">
                    <Col span={5} offset={2}>
                        {/*Form of L/C*/}
                        <Label itext="Form of L/C"/>
                    </Col>
                    <Col span={14}>
                    <SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/ledgrp/rec/lcrtyp"/>
                    </Col>
                </Row>
            </Col>
        </Row>
        <InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/letp//sysmod/usr/nam" />
        <CheckboxItem InputProps={bind("collflg")}  desp="Collateralized L/C" path="/ledgrp/rec/collflg" />	
        <SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/ledgrp/cbs/nom1/cur"/>
	    <InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/ledgrp/cbs/nom1/amt" />
        <CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/letp/aamp/aammod/addamtflg" />
        <InputItem InputProps={bind("nomtop")}   desp="Amount Tolerance - Positive" path="/ledgrp/rec/nomtop" />
	    <InputItem InputProps={bind("nomton")}   desp="Amount Tolerance - Negative" path="/ledgrp/rec/nomton" />
        <CheckboxItem InputProps={bind("ledgrp_preadvflg")}  desp="PreAdvice or Notification" path="/ledgrp/preadvflg" />
        <SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/ledgrp/rec/nomspc"/>
        <CheckboxItem InputProps={bind("resflg")}  desp="Reserved Contract" path="/ledgrp/rec/resflg" />
        <SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/ledgrp/cbs/max/cur"/>
	    <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/ledgrp/cbs/max/amt" />
        <DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/ledgrp/rec/opndat" />
        <DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/ledgrp/rec/shpdat" />
        <DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/ledgrp/rec/expdat" />
        <InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/ledgrp/rec/expplc" />
        <SelectItem InputProps={bind("cnfdet")}   desp="Confirmation Instructions from Iss.Bank" path="/ledgrp/rec/cnfdet"/>
        <SelectItem InputProps={bind("apprul")} code={CodeTable.apprul}  desp="Applicable Rules" path="/ledgrp/rec/apprul"/>
        <InputItem InputProps={bind("apprultxt")}  maxLength={35}  desp="Other Applicable Rules" path="/ledgrp/rec/apprultxt" />
    	<SelectItem InputProps={bind("shppar")}   desp="Partial Shipment" path="/ledgrp/rec/shppar"/>
        <SelectItem InputProps={bind("shptrs")}   desp="Transshipment" path="/ledgrp/rec/shptrs"/>


    
    <SelectItem InputProps={bind("lcrtyp")}   desp="Form of Documentary Credit" path="/ledgrp/rec/lcrtyp"/>


	<InputItem InputProps={bind("pts5_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/ben/pts/ref" />
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/ben/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onBenp_ptysel} desp="客户查询" path="/letp/benp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onBenp_sel} desp="查询" path="/letp/benp/sel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/letp//sysmod/usr/nam" />
	<TextAreaItem InputProps={bind("pts5_adrblk")} desp="SWIFT地址" path="/ledgrp/ben/pts/adrblk"/>
	<CheckboxItem InputProps={bind("inctrf")}  desp="Incoming Transfer" path="/ledgrp/rec/inctrf" />
	
	<InputItem InputProps={bind("pts7_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/iss/pts/ref" />
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/iss/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onIssp_ptysel} desp="客户查询" path="/letp/issp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onIssp_sel} desp="查询" path="/letp/issp/sel">
		<Label   itext="查询"/>
	</Button>
	
	<DatePickerItem InputProps={bind("preadvdt")}  desp="Date Pre-advised" path="/ledgrp/rec/preadvdt" />
	
	<DatePickerItem InputProps={bind("advdat")}  desp="Date Released on" path="/ledgrp/rec/advdat" />
	<TextAreaItem InputProps={bind("pts7_adrblk")} desp="SWIFT地址" path="/ledgrp/iss/pts/adrblk"/>
	<InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/apl/pts/ref" />
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/apl/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAplp_ptysel} desp="客户查询" path="/letp/aplp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAplp_sel} desp="查询" path="/letp/aplp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/ledgrp/apl/pts/adrblk"/>
	<CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/ledgrp/rec/revflg" />
	<CheckboxItem InputProps={bind("nonban")}  desp="Non-Bank Issuer" path="/ledgrp/rec/nonban" />
	<SelectItem InputProps={bind("avbwth")}   desp="Available with" path="/ledgrp/rec/avbwth"/>
	<TextAreaItem InputProps={bind("blk_mixdet")} desp="Mixed Payment Details" path="/ledgrp/blk/mixdet"/>
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/avb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAvbp_ptysel} desp="客户查询" path="/letp/avbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAvbp_sel} desp="查询" path="/letp/avbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts4_adrblk")} desp="SWIFT地址" path="/ledgrp/avb/pts/adrblk"/>
	<TextAreaItem InputProps={bind("blk_preper")} desp="Presentation Period" path="/ledgrp/blk/preper"/>
	<Button  type="primary" icon="search" onClick={this.onPreper_buttxmsel} desp="..." path="/letp/preper/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<SelectItem InputProps={bind("avbby")}   desp="Available by [AVBBY0]" path="/ledgrp/rec/avbby"/>
	<TextAreaItem InputProps={bind("blk_defdet")} desp="Deferred Payment Details" path="/ledgrp/blk/defdet"/>
	<TextAreaItem InputProps={bind("blk_feetxt")} desp="Additional Details to Code for Charges CHATO" path="/ledgrp/blk/feetxt"/>
	<Button  type="primary" icon="search" onClick={this.onCharia_buttxmsel} desp="..." path="/letp/charia/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<TextAreaItem InputProps={bind("blk_dftat")} desp="Drafts at" path="/ledgrp/blk/dftat"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdftat_buttxmsel} desp="..." path="/letp/lcrdftat/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/drw/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onDrwp_ptysel} desp="客户查询" path="/letp/drwp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onDrwp_sel} desp="查询" path="/letp/drwp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts6_adrblk")} desp="SWIFT地址" path="/ledgrp/drw/pts/adrblk"/>
	<SelectItem InputProps={bind("chato")}   desp="Own Charges Borne by" path="/ledgrp/rec/chato"/>
	<SelectItem InputProps={bind("stacty")}   desp="Country Code for Statistics" path="/ledgrp/rec/stacty"/>
	<InputItem InputProps={bind("shpfro")}  maxLength={65}  desp="Shipment from" path="/ledgrp/rec/shpfro" />
	<InputItem InputProps={bind("tenmaxday")}   desp="Maximum Tenor" path="/ledgrp/rec/tenmaxday" />
	<TextAreaItem InputProps={bind("porloa")} desp="Port of Loading" path="/ledgrp/rec/porloa"/>
	<TextAreaItem InputProps={bind("pordis")} desp="Port of Discharge" path="/ledgrp/rec/pordis"/>
	<InputItem InputProps={bind("shpto")}  maxLength={65}  desp="For Transportation to" path="/ledgrp/rec/shpto" />
	<TextAreaItem InputProps={bind("blk_shpper")} desp="Shipment Period" path="/ledgrp/blk/shpper"/>
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/adv/pts/ref" />
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/apb/pts/ref" />
	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/adv/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAdvp_ptysel} desp="客户查询" path="/letp/advp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/apb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onApbp_ptysel} desp="客户查询" path="/letp/apbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAdvp_sel} desp="查询" path="/letp/advp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onApbp_sel} desp="查询" path="/letp/apbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts1_adrblk")} desp="SWIFT地址" path="/ledgrp/adv/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/ledgrp/apb/pts/adrblk"/>
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/a2b/pts/ref" />
	<InputItem InputProps={bind("pts8_ref")}  maxLength={16}  desp="参考号" path="/ledgrp/rmb/pts/ref" />
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/a2b/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onA2bp_ptysel} desp="客户查询" path="/letp/a2bp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts8_extkey")}  maxLength={16}  desp="客户编号" path="/ledgrp/rmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onRmbp_ptysel} desp="客户查询" path="/letp/rmbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onA2bp_sel} desp="查询" path="/letp/a2bp/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onRmbp_sel} desp="查询" path="/letp/rmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts_adrblk")} desp="SWIFT地址" path="/ledgrp/a2b/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts8_adrblk")} desp="SWIFT地址" path="/ledgrp/rmb/pts/adrblk"/>
	<CheckboxItem InputProps={bind("aplbnkdirsnd")}  desp="Send Directly to Applicant's Bank" path="/ledgrp/rec/aplbnkdirsnd" />
	<SelectItem InputProps={bind("cnfins")}   desp="Confirmation Instructions to 2nd Adv.Bank" path="/ledgrp/rec/cnfins"/>
	<TextAreaItem InputProps={bind("blk_lcrgod")} desp="Description of Goods" path="/ledgrp/blk/lcrgod"/>
	<Button  type="primary" icon="search" onClick={this.onLcrgod_buttxmsel} desp="..." path="/letp/lcrgod/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<SelectItem InputProps={bind("stagod")}   desp="Goods Code for Statistics" path="/ledgrp/rec/stagod"/>
	<TextAreaItem InputProps={bind("blk_lcrdoc")} desp="Documents Required" path="/ledgrp/blk/lcrdoc"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdoc_buttxmsel} desp="..." path="/letp/lcrdoc/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<TextAreaItem InputProps={bind("blk_adlcnd")} desp="Additional Conditions" path="/ledgrp/blk/adlcnd"/>
	<Button  type="primary" icon="search" onClick={this.onAdlcnd_buttxmsel} desp="..." path="/letp/adlcnd/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/ledgrp/rec/redclsflg" />
	<TextAreaItem InputProps={bind("blk_insbnk")} desp="Instructions to Paying/Accepting/Negotiating Bank" path="/ledgrp/blk/insbnk"/>
	<Button  type="primary" icon="search" onClick={this.onInsbnk_buttxmsel} desp="..." path="/letp/insbnk/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>
		</div>
		)
	}
}
