import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitopn from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Row, Col, Popconfirm, Modal, Spin } from 'antd';
import Ptspta from '@/views/Public/Ptspta'
import { PtyPicker } from '@/components/Business-Library'
import Business from '@/views/Public/Business'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BasicScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litopn'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitopn()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('litopn/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]
    liaccv_liaccvgHeader=[
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原始金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="保证金账号" />, 
    		dataIndex:"ccvact",
    		key:"ccvact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvact,r2.ccvact),
    	},
    	{
    		title:<Label itext="业务币种" />, 
    		dataIndex:"covcur",
    		key:"covcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.covcur,r2.covcur),
    	},
    	{
    		title:<Label itext="转换金额" />, 
    		dataIndex:"covamt",
    		key:"covamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.covamt,r2.covamt),
    	},
    	{
    		title:<Label itext="汇率" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="保证金类型" />, 
    		dataIndex:"ccvtyp",
    		key:"ccvtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvtyp,r2.ccvtyp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.ccvtyp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="记账" />, 
    		dataIndex:"gleflg",
    		key:"gleflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.gleflg,r2.gleflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.onsel.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    liaall_liaallgHeader=[
    	{
    		title:<Label itext="业务种类" />, 
    		dataIndex:"bussec",
    		key:"bussec",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.bussec,r2.bussec),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.bussec.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="表外类型" />, 
    		dataIndex:"liatyp",
    		key:"liatyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.liatyp,r2.liatyp),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="表外账号" />, 
    		dataIndex:"acc",
    		key:"acc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acc,r2.acc),
    	},
    ]


    //按钮事件
    onA2bp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/a2bp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInip_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/inip_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/aplp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInsbnk_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/insbnk_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDocmod_doclst= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/docmod_doclst',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/rmbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdvp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/advp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts4_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts4_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts5_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts5_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts6_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts6_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts1_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts1_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaall_astlia= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/liaall_astlia',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/drwp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPreper_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/preper_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/avbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAplp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/aplp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onDrwp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/drwp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCharia_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/charia_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAvbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/avbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/benp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onA2bp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/a2bp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts7_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts7_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts8_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/pts8_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onInip_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/inip_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrdoc_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/lcrdoc_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaccv_recalccv= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/liaccv_recalccv',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onAdlcnd_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/adlcnd_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onBenp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/benp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    this.model.ownref = rtnmsg.data.ownref;    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理

                    
        })
    }
    onAdvp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/advp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCmbp_ptysel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/cmbp_ptysel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onRmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/rmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onCmbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/cmbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLcrgod_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('litopn/lcrgod_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
            
           <div style={{ position: 'relative' }}>
           <Business wrappedComponentRef={ref => (this.com = ref)} steps={this.props.steps} extra={this.props.extra} model={this.model} />

    {/*第一行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Reference*/}
                    <Label itext="Reference"/>
                </Col>
                <Col span={10}>
                    <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
                </Col>
                <Col span={4} offset={1}>
                     <Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
                         <Label   itext="获取"/>
                     </Button>
                </Col>
            </Row>
        </Col>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    <Label itext="Name"/>
                </Col>
                <Col span={14}>
                   <InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />
	            </Col>

            </Row>
        </Col>
    </Row>
    {/*第二行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*From of L/C*/}
                    <Label itext="From of L/C"/>
                </Col>
                <Col span={13}>
                    <SelectItem InputProps={bind("lcrtyp")} code={CodeTable.lcrtyp}  desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
                </Col>
            </Row>
        </Col>
    </Row>

    {/*第三行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*responsible user*/}
                   <Label itext="Responsiblr User"/>
                </Col>
                <Col span={8}>
                     <InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/sysmod/usr/nam" />
                </Col>
                <Col span={4} offset={1}>
                    <Label itext="ReservedContract"/>
                </Col>
                <Col span={2}>
                     <CheckboxItem InputProps={bind("resflg")}  desp="Reserved Contract" path="/lidgrp/rec/resflg" />
                </Col>
            </Row>
        </Col>
        <Col span={12}>
              <Ptspta  model={this.model} argArr={{ desc: "Applicant", prefix: 'pts1', url: 'litopn/aplp_ptysel', flg: 'C', datakey: '\\litp\\aplp\\ptslst' }} />
        </Col>
    </Row>
   {/*第四行*/}
   <Row>
       <Col span={12}>
           <Row className="row">
               <Col span={5} offset={2}>
                   {/*Nominal Amount*/}
                   <Label itext="Nominal Amount"/>
                </Col>
                <Col span={5}>
                   <SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
                </Col>
                <Col span={3} offset={1}> 
                      <InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
	            </Col>
                <Col span={2} offset={1}>
                    <Label itext="Add.Amount"/>
                </Col>
                <Col span={2} offset={1}>
                     <CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第五行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Amount Tolerance +/-*/}
                    <Label itext="Amount Tolerance +/-"/>
                </Col>
                <Col span={6}>
                    <InputItem InputProps={bind("nomtop")}   desp="Amount Tolerance - Positive" path="/lidgrp/rec/nomtop" />
                </Col>
                <Col span={6} offset={1}>
                    <InputItem InputProps={bind("nomton")}   desp="Amount Tolerance - Negative" path="/lidgrp/rec/nomton" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第六行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Amount Specification*/}
                   <Label itext="Amount Specification"/>
                </Col>
                <Col span={13}>
                     <SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/lidgrp/rec/nomspc"/>
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第七行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Maximum Amount*/}
                    <Label itext="Maximum Amount"/>
                </Col>
                <Col span={5}>
                   <SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/max/cur"/>
                </Col>
                <Col span={7} offset={1}>
                    <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/lidgrp/cbs/max/amt" />
                </Col>
            </Row>
        </Col>
        <Col span={12}>
              <Ptspta  model={this.model} argArr={{ desc: "Advising bank", prefix: 'pts2', url: 'litopn/advp_ptysel', flg: 'B', datakey: '\\litp\\advp\\ptslst' }} />
        </Col>
    </Row>
    {/*第八行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*L/C Issued on*/}
                    <Label itext="L/C Issued on"/>
                </Col>
                <Col span={14}>
                     <DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />
                </Col>
            </Row>
        </Col>
    </Row>

    {/*第九行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Date Pre-advised*/}
                    <Label itext="Date Pre-advised"/>
                </Col>
                <Col span={14}>
                    <DatePickerItem InputProps={bind("preadvdt")}  desp="Date Pre-advised" path="/lidgrp/rec/preadvdt" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第十行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Latest Shipment Date*/}
                    <Label itext="Latest Shipment Date"/>
                </Col>
                <Col span={14}>
                    <DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第十一行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*L/C Expiring on*/}
                   <Label itext="L/C Expiring on"/>
                </Col>
                <Col span={14}>
                    <DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第十二行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*in (Place)/counter*/}
                    <Label itext="in (Place)/counter"/>
                </Col>
                <Col span={14}>
                    <InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第十三行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Partial Shipm*/}
                    <Label itext="Partial Shipm"/>
                </Col>
                <Col span={14}>
                    <SelectItem InputProps={bind("shppar")} code={CodeTable.shppar}  desp="Partial Shipment" path="/lidgrp/rec/shppar"/>
                </Col>
            </Row>
        </Col>
        <Col span={12}>
              <Ptspta  model={this.model} argArr={{ desc: "Beneficiary", prefix: 'pts3', url: 'litopn/benp_ptysel', flg: 'C', datakey: '\\litp\\benp\\ptslst' }} />
        </Col>
    </Row>
    {/*第十四行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Transshipment*/}
                    <Label itext="Transshipment"/>
                </Col>
                <Col span={14}>
                <SelectItem InputProps={bind("shptrs")} code={CodeTable.shppar}  desp="Transshipment" path="/lidgrp/rec/shptrs"/> 
                </Col>
            </Row>
        </Col>
    </Row>
    {/*第十五行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Applicable Rule*/}
                    <Label itext="Applicable Rules"/>
                </Col>
                <Col span={14}>
                    <SelectItem InputProps={bind("apprul")} code={CodeTable.apprul}  desp="Applicable Rules" path="/lidgrp/rec/apprul"/>
                </Col>
            </Row>
        </Col>
    </Row>
  {/*第十六行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Other applicable Rules*/}
                    <Label itext="Other applicable Rules"/>
                </Col>
                <Col span={14}>
                     <InputItem InputProps={bind("apprultxt")}  maxLength={35}  desp="Other Applicable Rules" path="/lidgrp/rec/apprultxt" />   
                </Col>
            </Row>
        </Col>
        <Col span={12}>
            <Row className="row">
                <Col span={7} offset={2}>
                    <Label itext="Reimbursement Information"/>
                </Col>
                <Col span={12}>
                 <CheckboxItem InputProps={bind("rmbflg")}  desp="Reimbursement Information" path="/lidgrp/rec/rmbflg" />
                </Col>
            </Row>
        </Col>
    </Row>
{/*第十七行*/}
    <Row>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    {/*Confirm Instruction*/}
                    <Label itext="Confirm Instruction"/>
                </Col>
                <Col span={14}>
                   <SelectItem InputProps={bind("cnfdet")} code={CodeTable.cnfflg}  desp="Confirmation Instructions" path="/lidgrp/rec/cnfdet"/>
                </Col>
            </Row>
        </Col>
        <Col span={12}>
            <Row className="row">
                <Col span={5} offset={2}>
                    <Label itext="Revolving L/C"/>
                </Col>
                <Col span={14}>
                    <CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" /> 
                </Col>
            </Row>
        </Col>
    </Row>

   {/* <InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/apl/pts/extkey" />
	<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/apl/pts/ref" />

	<Button  type="primary" icon="search" onClick={this.onAplp_ptysel} desp="客户查询" path="/litp/aplp/ptysel">
		<Label   itext="查询"/>
	</Button>

	<Button  type="primary" icon="search" onClick={this.onAplp_sel} desp="查询" path="/litp/aplp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/lidgrp/apl/pts/adrblk"/>
	

	
	<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/adv/pts/ref" />

	<InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/adv/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAdvp_ptysel} desp="客户查询" path="/litp/advp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAdvp_sel} desp="查询" path="/litp/advp/sel">
		<Label   itext="查询"/>
	</Button>

	<TextAreaItem InputProps={bind("pts1_adrblk")} desp="SWIFT地址" path="/lidgrp/adv/pts/adrblk"/>
	<InputItem InputProps={bind("pts4_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ben/pts/ref" />
	<InputItem InputProps={bind("pts4_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ben/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onBenp_ptysel} desp="客户查询" path="/litp/benp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onBenp_sel} desp="查询" path="/litp/benp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts4_adrblk")} desp="SWIFT地址" path="/lidgrp/ben/pts/adrblk"/>
	
	<SelectItem InputProps={bind("avbwth")} code={CodeTable.avbwth}  desp="Available with" path="/lidgrp/rec/avbwth"/>
	<TextAreaItem InputProps={bind("blk_preper")} desp="Presentation Period" path="/lidgrp/blk/preper"/>
	<Button  type="primary" icon="search" onClick={this.onPreper_buttxmsel} desp="..." path="/litp/preper/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/avb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onAvbp_ptysel} desp="客户查询" path="/litp/avbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onAvbp_sel} desp="查询" path="/litp/avbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/lidgrp/avb/pts/adrblk"/>
	<CheckboxItem InputProps={bind("blk_preperflg")}  desp="Presentation Period modified" path="/lidgrp/blk/preperflg" />
	<TextAreaItem InputProps={bind("blk_feetxt")} desp="Additional Details to Code for Charges" path="/lidgrp/blk/feetxt"/>
	<Button  type="primary" icon="search" onClick={this.onCharia_buttxmsel} desp="..." path="/litp/charia/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby0}  desp="Available by" path="/lidgrp/rec/avbby"/>
	<TextAreaItem InputProps={bind("blk_defdet")} desp="Deferred Payment Details" path="/lidgrp/blk/defdet"/>
	<SelectItem InputProps={bind("chato")}   desp="Own Charges Borne by" path="/lidgrp/rec/chato"/>
	<TextAreaItem InputProps={bind("blk_dftat")} desp="Drafts at" path="/lidgrp/blk/dftat"/>
	<SelectItem InputProps={bind("stacty")}   desp="Country Code Risk Country" path="/lidgrp/rec/stacty"/>
	<InputItem InputProps={bind("pts6_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/drw/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onDrwp_ptysel} desp="客户查询" path="/litp/drwp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onDrwp_sel} desp="查询" path="/litp/drwp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts6_adrblk")} desp="SWIFT地址" path="/lidgrp/drw/pts/adrblk"/>
	<TextAreaItem InputProps={bind("blk_mixdet")} desp="Mixed Payment Details" path="/lidgrp/blk/mixdet"/>
	<InputItem InputProps={bind("shpfro")}  maxLength={65}  desp="Shipment from" path="/lidgrp/rec/shpfro" />
	<InputItem InputProps={bind("tenmaxday")}   desp="Maximum tenor in days" path="/lidgrp/rec/tenmaxday" />
	<InputItem InputProps={bind("porloa")}  maxLength={65}  desp="Port of Loading" path="/lidgrp/rec/porloa" />
	<InputItem InputProps={bind("pordis")}  maxLength={65}  desp="Port of Discharge" path="/lidgrp/rec/pordis" />
	<InputItem InputProps={bind("shpto")}  maxLength={65}  desp="For Transportation to" path="/lidgrp/rec/shpto" />
	<TextAreaItem InputProps={bind("blk_shpper")} desp="Shipment Period" path="/lidgrp/blk/shpper"/>
	<InputItem InputProps={bind("pts7_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/ini/pts/ref" />
	<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/a2b/pts/ref" />
	<InputItem InputProps={bind("pts7_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/ini/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onInip_ptysel} desp="客户查询" path="/litp/inip/ptysel">
		<Label   itext="查询"/>
	</Button>
	<InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/a2b/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onA2bp_ptysel} desp="客户查询" path="/litp/a2bp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onInip_sel} desp="查询" path="/litp/inip/sel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onA2bp_sel} desp="查询" path="/litp/a2bp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts7_adrblk")} desp="SWIFT地址" path="/lidgrp/ini/pts/adrblk"/>
	<TextAreaItem InputProps={bind("pts_adrblk")} desp="SWIFT地址" path="/lidgrp/a2b/pts/adrblk"/>
	<InputItem InputProps={bind("pts8_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/rmb/pts/ref" />
	<Label value={this.model.litp_avblab}   desp="Label Available with Bank" path="/litp/avblab" />
	<InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/lidgrp/avb/pts/ref" />
	<InputItem InputProps={bind("pts8_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/rmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onRmbp_ptysel} desp="客户查询" path="/litp/rmbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onRmbp_sel} desp="查询" path="/litp/rmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts8_adrblk")} desp="SWIFT地址" path="/lidgrp/rmb/pts/adrblk"/>
	<InputItem InputProps={bind("pts5_extkey")}  maxLength={16}  desp="客户编号" path="/lidgrp/cmb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onCmbp_ptysel} desp="客户查询" path="/litp/cmbp/ptysel">
		<Label   itext="查询"/>
	</Button>
	<Button  type="primary" icon="search" onClick={this.onCmbp_sel} desp="查询" path="/litp/cmbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts5_adrblk")} desp="SWIFT地址" path="/lidgrp/cmb/pts/adrblk"/>
	<TextAreaItem InputProps={bind("blk_lcrgod")} desp="Description of Goods" path="/lidgrp/blk/lcrgod"/>
	<Button  type="primary" icon="search" onClick={this.onLcrgod_buttxmsel} desp="..." path="/litp/lcrgod/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<SelectItem InputProps={bind("stagod")}   desp="Goods Code" path="/lidgrp/rec/stagod"/>
	<TextAreaItem InputProps={bind("blk_lcrdoc")} desp="Documents Required" path="/lidgrp/blk/lcrdoc"/>
	<Button  type="primary" icon="search" onClick={this.onLcrdoc_buttxmsel} desp="..." path="/litp/lcrdoc/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<TextAreaItem InputProps={bind("blk_adlcnd")} desp="Additional Conditions" path="/lidgrp/blk/adlcnd"/>
	<Button  type="primary" icon="search" onClick={this.onAdlcnd_buttxmsel} desp="..." path="/litp/adlcnd/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<CheckboxItem InputProps={bind("redclsflg")}  desp="Red/Green Clause" path="/lidgrp/rec/redclsflg" />
	<TextAreaItem InputProps={bind("blk_insbnk")} desp="Instructions to Paying/Accepting/Negotiating Bank" path="/lidgrp/blk/insbnk"/>
	<Button  type="primary" icon="search" onClick={this.onInsbnk_buttxmsel} desp="..." path="/litp/insbnk/buttxmsel">
		<Label   itext="..."/>
	</Button>
	<Button  type="primary"  onClick={this.onLiaall_astlia} desp="表外加载" path="/liaall/astlia">
		<Label   itext="表外加载"/>
	</Button>
	<Table rowKey="inr" columns={this.liaall_liaallgHeader}  dataSource={this.model.liaall_liaallg}   path="/liaall/liaallg"/>
	<SelectItem InputProps={bind("liaccv_concur")} code={CodeTable.curtxt}  desp="业务结算币种" path="/liaall/liaccv/concur"/>
	<InputItem InputProps={bind("liaccv_newamt")}   desp="业务金额" path="/liaall/liaccv/newamt" />
	<InputItem InputProps={bind("liaccv_cshpct")}   desp="保证金应收比例" path="/liaall/liaccv/cshpct" />
	<InputItem InputProps={bind("liaccv_chgamt")}   desp="变动金额" path="/liaall/liaccv/chgamt" />
	<InputItem InputProps={bind("liaccv_relcshpct")}   desp="保证金实收比例" path="/liaall/liaccv/relcshpct" />
	<InputItem InputProps={bind("liaccv_pctresamt")}   desp="应收/支保证金" path="/liaall/liaccv/pctresamt" />
	<Button  type="primary"  onClick={this.onLiaccv_recalccv} desp="汇率重算" path="/liaall/liaccv/recalccv">
		<Label   itext="汇率重算"/>
	</Button>
	<Table rowKey="inr" columns={this.liaccv_liaccvgHeader}  dataSource={this.model.liaccv_liaccvg}   path="/liaall/liaccv/liaccvg"/>
	<InputItem InputProps={bind("liaccv_totcovamt")}   desp="保证金合计" path="/liaall/liaccv/totcovamt" />
	<SelectItem InputProps={bind("setmod_doccur")} code={CodeTable.curtxt}  desp="document currency" path="/setmod/doccur"/>
	<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
	<Button  type="primary"  onClick={this.onSetmod_ast} desp="加载账务" path="/setmod/ast">
		<Label   itext="加载账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_feemac")}  maxLength={200}  desp="FEEMAC" path="/setmod/feemac" />
	<Button  type="primary"  onClick={this.onSetmod_recal} desp="重算账务" path="/setmod/recal">
		<Label   itext="重算账务"/>
	</Button>
	<InputItem InputProps={bind("setmod_setmac")}  maxLength={200}  desp="SETMAC" path="/setmod/setmac" />
	<Table rowKey="inr" columns={this.fegmod_feslstHeader}  dataSource={this.model.fegmod_feslst}   path="/setmod/setfeg/fegmod/feslst"/>
	<Table rowKey="inr" columns={this.glgmod_glslstHeader}  dataSource={this.model.glgmod_glslst}   path="/setmod/setglg/glgmod/glslst"/>
	<Button  type="primary"  onClick={this.onGlemod_rebook} desp="分录加载" path="/setmod/glemod/rebook">
		<Label   itext="分录加载"/>
	</Button>
	<Table rowKey="inr" columns={this.glemod_glelstHeader}  dataSource={this.model.glemod_glelst}   path="/setmod/glemod/glelst"/>
	<Button  type="primary"  onClick={this.onTrndoc_reldoc} desp="面函加载" path="/trnmod/trndoc/reldoc">
		<Label   itext="面函加载"/>
	</Button>
	<InputItem InputProps={bind("trndoc_doccod")}  maxLength={16}  desp="面函码值" path="/trnmod/trndoc/doccod" />
	<InputItem InputProps={bind("trndoc_cortyp")}  maxLength={3}  desp="Per Medium" path="/trnmod/trndoc/cortyp" />
	<Button  type="primary"  onClick={this.onTrndoc_butshw} desp="show doc." path="/trnmod/trndoc/butshw">
		<Label   itext="展示"/>
	</Button>
	<InputItem InputProps={bind("trndoc_docpth")}  maxLength={100}  desp="面函路径" path="/trnmod/trndoc/docpth" />
	<InputItem InputProps={bind("spt_inr")}  maxLength={8}  desp="唯一编号" path="/sysmod/spt/inr" />
	<Table rowKey="inr" columns={this.docmod_doclstHeader}  dataSource={this.model.docmod_doclst}   path="/trnmod/trndoc/docmod/doclst"/>
	<SelectItem InputProps={bind("cnybop_cnyflg")} code={CodeTable.cnyflg}  desp="是否报送跨境人民币2101表" path="/cnybop/cnyflg"/>
	<SelectItem InputProps={bind("cnybop_traflg")} code={CodeTable.traflg}  desp="是否报送跨境人民币2107表" path="/cnybop/traflg"/>
	<SelectItem InputProps={bind("cnybop_outflg")} code={CodeTable.outflg}  desp="是否报送跨境人民币2111表" path="/cnybop/outflg"/>
	<SelectItem InputProps={bind("cnybop_libflg")} code={CodeTable.libflg}  desp="是否报送跨境人民币2106表" path="/cnybop/libflg"/>
	<SelectItem InputProps={bind("cnybop_vouflg")} code={CodeTable.vouflg}  desp="是否报送跨境人民币2122表" path="/cnybop/vouflg"/>
	<Button  type="primary" icon="save"
		  onClick={this.onSav} desp="Save" path="/mtabut/sav">
		<Label   itext="提交"/>
	</Button>
	<Button  type="primary"  onClick={this.onChk} desp="Check" path="/mtabut/chk">
		<Label   itext="检核"/>
	</Button>
	<Button  type="primary"  onClick={this.onPed} desp="暂存" path="/mtabut/ped">
		<Label   itext="暂存"/>
	</Button>
	<Button  type="primary"  onClick={this.onExi} desp="Exit" path="/mtabut/exi">
		<Label   itext="退出"/>
	</Button>*/}
		</div>
		)
	}
}
